==> qtjambi-webenginecore-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiWebEngineCore/QWebEngineUrlRequestJob_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtWebEngineCore/qwebengineurlrequestjob.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>
#include <QtCore/qbytearray.h>
#include <QtCore/QMap>
#include <QtCore/qiodevice.h>
#include <QtCore/qobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/QList>
#include <QtCore/qcoreevent.h>
#include <QtCore/qtimer.h>
#include <QtCore/qregexp.h>
#include <QtCore/qthread.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qmetaobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineUrlRequestJob::fail(QWebEngineUrlRequestJob::Error)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_fail_1native_1QWebEngineUrlRequestJob_1Error__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint error0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::fail(QWebEngineUrlRequestJob::Error)", __qt_this)
        QWebEngineUrlRequestJob::Error __qt_error0 = qtjambi_cast<QWebEngineUrlRequestJob::Error>(__jni_env, error0);
        __qt_this->fail(QWebEngineUrlRequestJob::Error(__qt_error0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestJob::initiator()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_initiator_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::initiator()const", __qt_this)
        QUrl __qt_return_value = __qt_this->initiator();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestJob::redirect(QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_redirect_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID url0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::redirect(QUrl)", __qt_this)
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __qt_this->redirect(__qt_url0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestJob::reply(QByteArray,QIODevice*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_reply_1native_1cref_1QByteArray_1QIODevice_1ptr__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID contentType0,
 QtJambiNativeID device1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::reply(QByteArray,QIODevice*)", __qt_this)
        const QByteArray& __qt_contentType0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(contentType0);
        QIODevice* __qt_device1 = QtJambiAPI::objectFromNativeId<QIODevice>(device1);
        __qt_this->reply(__qt_contentType0, __qt_device1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestJob::requestHeaders()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_requestHeaders_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::requestHeaders()const", __qt_this)
        QMap<QByteArray, QByteArray> __qt_return_value = __qt_this->requestHeaders();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestJob::requestMethod()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_requestMethod_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::requestMethod()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->requestMethod();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestJob::requestUrl()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_requestUrl_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::requestUrl()const", __qt_this)
        QUrl __qt_return_value = __qt_this->requestUrl();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWebEngineUrlRequestJob(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QWebEngineUrlRequestJob>("QWebEngineUrlRequestJob", "io/qt/webengine/core/QWebEngineUrlRequestJob");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QWebEngineUrlRequestJob::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QWebEngineUrlRequestJob::Error>("QWebEngineUrlRequestJob::Error", "io/qt/webengine/core/QWebEngineUrlRequestJob$Error");
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiWebEngineCore/QWebEngineUrlRequestJob_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebengineurlrequestjob.h>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineUrlRequestJob::fail(QWebEngineUrlRequestJob::Error)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_fail_1native_1QWebEngineUrlRequestJob_1Error__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint error0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::fail(QWebEngineUrlRequestJob::Error)", __qt_this)
        QWebEngineUrlRequestJob::Error __qt_error0 = qtjambi_cast<QWebEngineUrlRequestJob::Error>(__jni_env, error0);
        __qt_this->fail(QWebEngineUrlRequestJob::Error(__qt_error0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestJob::initiator()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_initiator_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::initiator()const", __qt_this)
        QUrl __qt_return_value = __qt_this->initiator();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestJob::redirect(QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_redirect_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID url0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::redirect(QUrl)", __qt_this)
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __qt_this->redirect(__qt_url0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestJob::reply(QByteArray,QIODevice*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_reply_1native_1cref_1QByteArray_1QIODevice_1ptr__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID contentType0,
 QtJambiNativeID device1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::reply(QByteArray,QIODevice*)", __qt_this)
        const QByteArray& __qt_contentType0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(contentType0);
        QIODevice* __qt_device1 = QtJambiAPI::objectFromNativeId<QIODevice>(device1);
        __qt_this->reply(__qt_contentType0, __qt_device1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestJob::requestHeaders()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_requestHeaders_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::requestHeaders()const", __qt_this)
        QMap<QByteArray, QByteArray> __qt_return_value = __qt_this->requestHeaders();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestJob::requestMethod()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_requestMethod_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::requestMethod()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->requestMethod();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestJob::requestUrl()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestJob_requestUrl_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestJob *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestJob::requestUrl()const", __qt_this)
        QUrl __qt_return_value = __qt_this->requestUrl();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWebEngineUrlRequestJob(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QWebEngineUrlRequestJob>("QWebEngineUrlRequestJob", "io/qt/webengine/core/QWebEngineUrlRequestJob");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QWebEngineUrlRequestJob::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QWebEngineUrlRequestJob::Error>("QWebEngineUrlRequestJob::Error", "io/qt/webengine/core/QWebEngineUrlRequestJob$Error");
// END: enums and flags
}
